;;; @(#) Ksnet
;;; lumped stream kinematic wave model
;;; $Lastupdate: Mon Jan 15 21:14:32 2001 $

------------------------------------------------------------------------
* summary

This directory contains ksnet.h,cc and the sample files of the simulations.
These files are available on ohymos-2.0 or later.

 o ksnet.h : definition of the class Ksnet
 o ksnet.cc : implimentation of the class Ksnet

The class Ksnet is a lumped stream kinematic wave model derived from the 
class Element, which is contained in the ohymos directory. See Takasao et.
al. (1994) about the theory of the model.

------------------------------------------------------------------------
* class name

  Ksnet

------------------------------------------------------------------------
* receive ports

Ksnet has two types of receive ports. One is for receiving upstream inflow
discharges, and the other is for receiving lateral inflow discharges from 
drainage areas. The numbers of the receive ports are variable, which are 
given in the constructor of Ksnet. The type of both ports is Receive<double>. 

The object_name of the ports for upstream inflow discharge is "rpu" and 
the object_name of the ports for lateral inflow discharge is "rpl".
The object_numbers are [0,1,...,n-1] (n is the number of the each port).
The unit of the discharges is m3/s.

------------------------------------------------------------------------
* send ports

Ksnet has a send port for sending outflow discharge from stream network.
The port type is Send<double>. 

The object_name is "sp" and the object_number is 0. The unit of the discharge
is m3/s.

------------------------------------------------------------------------
* arguments of the constructor of class Ksnet

The arguments of the constructor are as follows:

object_name
object_number
name of the file for connecting stream segments (will be described below)
number of upstream inflow discharges
number of lateral inflow discharges
number of stream segments

------------------------------------------------------------------------
* input files

These files are required as input files:

 o file for connecting stream segments
 o parameter file
 o initial state file

------------------------------------------------------------------------
** file for connecting stream segments

Assume the stream network shown below.

ex.) 1    2
      \  /
     4 \/ 5   3
        \    /
       7 \  / 6
          \/
           \
          8 \

The digits in this figure are the stream segment numbers, which must be
numbered from upper stream segment. Segment 1, 2 and 3 do not exist 
actually. They mean inflow discharges.

The file for connecting these segments is as follows:

@begin{connection_file} ------------------------------------------------
# The entries must be recorded from upper segments.
# The format is as follows:
# 
# num : a b c ...
#     num       -> number of upper segments
#     a,b,c,... -> segment numbers of upper segments
#
# A line started by '#' or blank line is discarded.

1 : 1
1 : 2
1 : 3
2 : 4 5
2 : 6 7
@end{connection_file} --------------------------------------------------

------------------------------------------------------------------------
** ohymos parameter file

Function Kinem::Set_parameter(FILE* fp) reads a parameter file.
The format is as follows:

  l_1 b_1 g_1 n_1 p_1
  l_2 b_2 g_2 n_2 p_2
  ...
  l_n b_n g_n n_n p_n

where

  l_i : length of the segment i
  b_i : width of the segment i
  g_i : gradient of the segment i
  n_i : manning coefficient of the segment i
  p_i : constant p used in A = K * Q^p for the segment i (A: flow
        cross sectional area, Q: discharge, K: constant)

------------------------------------------------------------------------
** ohymos initial state file

Function Kinem::Set_initial_state(FILE* fp) reads an initial state file.
Simulation starting time is recorded in this file.

------------------------------------------------------------------------
* compile

To compile, type

% make

then the executable files tksnet will be generated. 

To execute, type

% ./tksnet

------------------------------------------------------------------------
* bibliography

Takuma TAKASAO, Michiharu SHIIBA and Yutaka ICHIKAWA (1994) :
Scale-up of a distributed runoff model, 
Annual Journal of Hydraulic Engineering, JSCE, 38, pp. 809 -- 812.

;;; Local Variables: ***
;;; mode: Outline ***
;;; indent-tabs-mode: nil ***
;;; tab-width: 8 ***
;;; End: ***
